@@ -31,7 +31,7 @@ class Sync:
         if not os.path.exists(self.config["media_dir"]):
             os.mkdir(self.config["media_dir"])
 
-    def sync(self, ids=None):
+    def sync(self, ids=None, from_id=None):
         """
         Sync syncs messages from Telegram from the last synced message
         into the local SQLite DB.
@@ -39,12 +39,12 @@ class Sync:
 
         if ids:
             last_id, last_date = (ids, None)
+            logging.info("fetching message id={}".format(ids))
+        elif from_id:
+            last_id, last_date = (from_id, None)
+            logging.info("fetching from last message id={}".format(last_id))
         else:
             last_id, last_date = self.db.get_last_message_id()
-
-        if ids:
-            logging.info("fetching message id={}".format(ids))
-        elif last_id:
             logging.info("fetching from last message id={} ({})".format(
                 last_id, last_date))
 
@@ -106,17 +106,17 @@ class Sync:
                     return takeout_client
                 except errors.TakeoutInitDelayError as e:
                     logging.info(
-                        "please allow the data export request received from Telegram on your other device. "
-                        "You can also wait for {} seconds.".format(e.seconds))
+                        "please allow the data export request received from Telegram on your device. "
+                        "you can also wait for {} seconds.".format(e.seconds))
                     logging.info("press Enter key after allowing the data export request to continue..")
                     input()
                     logging.info("trying again.. ({})".format(retry + 2))
                 except errors.TakeoutInvalidError:
-                    logging.info("takeout invalidated, please delete the session.session file and try again.")
-                    quit()
+                    logging.info("takeout invalidated. delete the session.session file and try again.")
+                    raise
             else:
-                logging.info("quitting")
-                quit()
+                logging.info("could not initiate takeout.")
+                raise(Exception("could not initiate takeout."))
         else:
             return client
 
